==> nextcloud-app-spreed-1%3A8.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/zh_TW.js <==
OC.L10N.register(
    "spreed",
    {
    "Talk" : "交談",
    "Guest" : "訪客",
    "You started a call" : "您打了一通電話",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Leave call" : "離開通話",
    "Limit to groups" : "限制給特定群組",
    "Everyone" : "所有人",
    "Save changes" : "儲存變更",
    "Saving …" : "儲存中 ...",
    "Saved!" : "已儲存!",
    "None" : "無",
    "User" : "使用者",
    "Disabled" : "停用",
    "Moderators" : "主持人",
    "Users" : "使用者",
    "Beta" : "Beta 測試版",
    "Name" : "名稱",
    "General settings" : "一般設定",
    "Off" : "關閉",
    "Validate SSL certificate" : "驗證 SSL憑證",
    "Saved" : "儲存",
    "UDP and TCP" : "UDP 和 TCP",
    "UDP only" : "僅UDP",
    "TCP only" : "僅TCP",
    "Copy link" : "複製連結",
    "Mute audio (m)" : "靜音 (m)",
    "Mute audio" : "靜音",
    "Disable video" : "停用視訊",
    "Favorite" : "我的最愛",
    "Leave conversation" : "離開對話",
    "Delete conversation" : "刪除對話",
    "Remove from favorites" : "取消我的最愛",
    "Add to favorites" : "加到我的最愛",
    "Contacts" : "聯絡人",
    "Loading" : "載入中",
    "Groups" : "群組",
    "Invalid path selected" : "所選的路徑無效",
    "Error" : "錯誤",
    "Password protect" : "密碼防護",
    "Back" : "返回",
    "Close" : "關閉",
    "Conversation name" : "對話名稱",
    "Reply" : "回覆",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Send message" : "傳送訊息",
    "File to share" : "要分享的檔案",
    "moderator" : "主持人",
    "guest" : "訪客",
    "No results" : "沒有符合搜尋的項目",
    "Participants" : "參與者",
    "Chat" : "聊天",
    "Projects" : "專案項目",
    "Settings" : "設定",
    "Edit" : "編輯",
    "Start call" : "通話",
    "Dismiss" : "取消",
    "Rename conversation" : "重新命名對話",
    "Share link" : "分享連結",
    "Password protection" : "密碼保護",
    "Enter a password" : "輸入密碼",
    "Exit fullscreen (f)" : "離開全螢幕 (f)",
    "Fullscreen (f)" : "全螢幕 (f)",
    "Grid view" : "網格檢視",
    "Join a conversation or start a new one" : "加入一個對話或者開一個新的",
    "Say hi to your friends and colleagues!" : "跟大家打招呼",
    "The password is wrong. Try again." : "密碼錯誤，請重試",
    "Password" : "密碼",
    "Android app" : "安卓應用",
    "iOS app" : "蘋果應用",
    "Enter name for a new conversation" : "輸入新對話名稱",
    "New conversation …" : "新對話",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 複製",
    "Room name can not be empty" : "名稱不能空白",
    "Password required" : "請輸入密碼",
    "Cancel" : "取消",
    "Submit" : "送出",
    "Guests" : "訪客",
    "Change password" : "變更密碼",
    "Set password" : "設定密碼",
    "Rename" : "重新命名",
    "Conversation with {name}" : "和 {name} 的談話",
    "You" : "您",
    "No messages yet, start the conversation!" : "尚無訊息，開始對話！",
    "New message …" : "新訊息 ...",
    "Send" : "傳送",
    "Share" : "分享",
    "[Unknown user name]" : "[未知的使用者名稱]",
    "Error while sharing" : "分享時發生錯誤",
    "Share screen" : "分享螢幕",
    "Screensharing is not supported by your browser." : "您的瀏覽器並不支援螢幕分享",
    "Favorited" : "已加入最愛",
    "Limit app usage to groups." : "限制群組的使用率:"
},
"nplurals=1; plural=0;");

==> nextcloud-app-spreed-1%3A9.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/zh_TW.js <==
OC.L10N.register(
    "spreed",
    {
    "Talk" : "交談",
    "Guest" : "訪客",
    "You started a call" : "您打了一通電話",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Leave call" : "離開通話",
    "Limit to groups" : "限制給特定群組",
    "Everyone" : "所有人",
    "Save changes" : "儲存變更",
    "Saving …" : "儲存中 ...",
    "Saved!" : "已儲存!",
    "None" : "無",
    "User" : "使用者",
    "Disabled" : "停用",
    "Moderators" : "主持人",
    "Users" : "使用者",
    "Beta" : "Beta 測試版",
    "Name" : "名稱",
    "General settings" : "一般設定",
    "Off" : "關閉",
    "Validate SSL certificate" : "驗證 SSL憑證",
    "Saved" : "儲存",
    "UDP and TCP" : "UDP 和 TCP",
    "UDP only" : "僅UDP",
    "TCP only" : "僅TCP",
    "Copy link" : "複製連結",
    "Mute audio (m)" : "靜音 (m)",
    "Mute audio" : "靜音",
    "Disable video" : "停用視訊",
    "You" : "您",
    "Favorite" : "我的最愛",
    "Leave conversation" : "離開對話",
    "Delete conversation" : "刪除對話",
    "Remove from favorites" : "取消我的最愛",
    "Add to favorites" : "加到我的最愛",
    "Loading" : "載入中",
    "Groups" : "群組",
    "Invalid path selected" : "所選的路徑無效",
    "Error" : "錯誤",
    "Password protect" : "密碼防護",
    "Back" : "返回",
    "Close" : "關閉",
    "Conversation name" : "對話名稱",
    "Reply" : "回覆",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Send message" : "傳送訊息",
    "File to share" : "要分享的檔案",
    "moderator" : "主持人",
    "guest" : "訪客",
    "No results" : "沒有符合搜尋的項目",
    "Add users or groups" : "增加使用者或者群組",
    "Participants" : "參與者",
    "Chat" : "聊天",
    "Projects" : "專案項目",
    "Settings" : "設定",
    "Edit" : "編輯",
    "Start call" : "通話",
    "Dismiss" : "取消",
    "Rename conversation" : "重新命名對話",
    "Share link" : "分享連結",
    "Password protection" : "密碼保護",
    "Enter a password" : "輸入密碼",
    "Exit fullscreen (f)" : "離開全螢幕 (f)",
    "Fullscreen (f)" : "全螢幕 (f)",
    "Grid view" : "網格檢視",
    "Join a conversation or start a new one" : "加入一個對話或者開一個新的",
    "Say hi to your friends and colleagues!" : "跟大家打招呼",
    "The password is wrong. Try again." : "密碼錯誤，請重試",
    "Password" : "密碼",
    "Android app" : "安卓應用",
    "iOS app" : "蘋果應用",
    "Enter name for a new conversation" : "輸入新對話名稱",
    "New conversation …" : "新對話",
    "Copy" : "複製",
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "按下 ⌘-C 來複製",
    "Press Ctrl-C to copy." : "按下 Ctrl-C 複製",
    "Room name can not be empty" : "名稱不能空白",
    "Password required" : "請輸入密碼",
    "Cancel" : "取消",
    "Submit" : "送出",
    "Guests" : "訪客",
    "Change password" : "變更密碼",
    "Set password" : "設定密碼",
    "Rename" : "重新命名",
    "Conversation with {name}" : "和 {name} 的談話",
    "No messages yet, start the conversation!" : "尚無訊息，開始對話！",
    "New message …" : "新訊息 ...",
    "Send" : "傳送",
    "Share" : "分享",
    "[Unknown user name]" : "[未知的使用者名稱]",
    "Error while sharing" : "分享時發生錯誤",
    "Share screen" : "分享螢幕",
    "Screensharing is not supported by your browser." : "您的瀏覽器並不支援螢幕分享",
    "Favorited" : "已加入最愛",
    "Limit app usage to groups." : "限制群組的使用率:",
    "Contacts" : "聯絡人"
},
"nplurals=1; plural=0;");
